@@ -90,6 +90,7 @@ LOG_DIR="$(log_dir_for "$MODEL" "$PROJECT_NAME")"
 MODEL_LOG="$LOG_DIR/model.log"
 RUN_LOG="$LOG_DIR/run_bot.log"
 POINTER_FILE="$LOG_DIR/${MODEL_POINTER_BASENAME:-current_session.txt}"
+LOCK_FILE="${SESSION_LOCK_FILE:-$LOG_DIR/${MODEL_POINTER_LOCK_BASENAME:-session_lock.json}}"
 TMUX_SESSION="$(tmux_session_for "$PROJECT_NAME")"
 
 expand_model_workdir() {
@@ -167,6 +168,8 @@ export MODEL_SESSION_ROOT
 export MODEL_SESSION_GLOB
 export SESSION_POINTER_FILE="$POINTER_FILE"
 export CODEX_SESSION_FILE_PATH="$POINTER_FILE"
+export SESSION_LOCK_FILE="$LOCK_FILE"
+export SESSION_LOCK_FILE_PATH="$LOCK_FILE"
 export TMUX_SESSION="$TMUX_SESSION"
 export TMUX_LOG="$MODEL_LOG"
 export PROJECT_NAME="$PROJECT_NAME"
