@@ -1,10 +1,12 @@
-"""aiogram FSM 状态定义。"""
+"""aiogram FSM state definitions."""
 from __future__ import annotations
 
 from aiogram.fsm.state import State, StatesGroup
 
 
 class TaskCreateStates(StatesGroup):
+    """States for the guided task creation flow."""
+
     waiting_title = State()
     waiting_type = State()
     waiting_description = State()
@@ -12,6 +14,8 @@ class TaskCreateStates(StatesGroup):
 
 
 class TaskEditStates(StatesGroup):
+    """States for editing existing tasks."""
+
     waiting_task_id = State()
     waiting_field_choice = State()
     waiting_new_value = State()
@@ -19,13 +23,15 @@ class TaskEditStates(StatesGroup):
 
 
 class TaskNoteStates(StatesGroup):
+    """States for appending notes to a task."""
+
     waiting_task_id = State()
     waiting_content = State()
     waiting_type = State()
 
 
 class TaskBugReportStates(StatesGroup):
-    """缺陷报告流程状态。"""
+    """States for the defect reporting flow."""
 
     waiting_description = State()
     waiting_reproduction = State()
@@ -34,22 +40,26 @@ class TaskBugReportStates(StatesGroup):
 
 
 class TaskDescriptionStates(StatesGroup):
-    """任务描述编辑流程状态。"""
+    """States for editing task descriptions."""
 
     waiting_content = State()
     waiting_confirm = State()
 
 
 class TaskPushStates(StatesGroup):
+    """States for sending supplemental task updates."""
+
     waiting_choice = State()
     waiting_supplement = State()
 
 
 class TaskListSearchStates(StatesGroup):
+    """States for searching within the task list."""
+
     waiting_keyword = State()
 
 
 class ProjectDeleteStates(StatesGroup):
-    """Master 项目删除确认流程的状态定义。"""
+    """States for confirming master project deletion."""
 
     confirming = State()
